@@ -87,7 +87,7 @@ our $re_cjk = qr/(?:
                  |   \p{Block=CJK_Unified_Ideographs_Extension_A}
                  |   \p{Block=CJK_Unified_Ideographs_Extension_B}
                      #|   \p{Block=CJK_Unified_Ideographs_Extension_C}
-                     [ï¼ã]
+                     [ÃÂ¯ÃÂ¼ÃÂÃÂ£ÃÂÃÂ]
                  )/x;
 our $re_cjk_class = qr/[
                            \p{Block=CJK_Compatibility}
@@ -100,7 +100,7 @@ our $re_cjk_class = qr/[
                            \p{Block=CJK_Unified_Ideographs}
                            \p{Block=CJK_Unified_Ideographs_Extension_A}
                            \p{Block=CJK_Unified_Ideographs_Extension_B}
-                           ï¼ã
+                           ÃÂ¯ÃÂ¼ÃÂÃÂ£ÃÂÃÂ
                       ]/x;
 our $re_cjk_negclass = qr/[^
                               \p{Block=CJK_Compatibility}
@@ -113,7 +113,7 @@ our $re_cjk_negclass = qr/[^
                               \p{Block=CJK_Unified_Ideographs}
                               \p{Block=CJK_Unified_Ideographs_Extension_A}
                               \p{Block=CJK_Unified_Ideographs_Extension_B}
-                              ï¼ã
+                              ÃÂ¯ÃÂ¼ÃÂÃÂ£ÃÂÃÂ
                       ]/x;
 
 sub _wrap {
@@ -180,8 +180,8 @@ sub _wrap {
 
         my @words0; # (WORD1, WORD1_IS_CJK?, WS_AFTER?, WORD2, WORD2_IS_CJK?, WS_AFTER?, ...)
         # we differentiate/split between CJK "word" (cluster of CJK letters,
-        # really) and non-CJK word, e.g. "æå¾ç±ä½ myå¯ç±çand beautiful,
-        # beautiful wife" is split to ["æå¾ç±ä½ ", "my", "å¯ç±ç", "and",
+        # really) and non-CJK word, e.g. "ÃÂ¦ÃÂÃÂÃÂ¥ÃÂ¾ÃÂÃÂ§ÃÂÃÂ±ÃÂ¤ÃÂ½ÃÂ myÃÂ¥ÃÂÃÂ¯ÃÂ§ÃÂÃÂ±ÃÂ§ÃÂÃÂand beautiful,
+        # beautiful wife" is split to ["ÃÂ¦ÃÂÃÂÃÂ¥ÃÂ¾ÃÂÃÂ§ÃÂÃÂ±ÃÂ¤ÃÂ½ÃÂ ", "my", "ÃÂ¥ÃÂÃÂ¯ÃÂ§ÃÂÃÂ±ÃÂ§ÃÂÃÂ", "and",
         # "beautiful,", "beautiful", "wife"]. we do this because CJK word can be
         # line-broken on a per-letter basis, as they don't separate words with
         # whitespaces.
@@ -416,7 +416,7 @@ Text::WideChar::Util - Routines for text containing wide characters
 
 =head1 VERSION
 
-This document describes version 0.14 of Text::WideChar::Util (from Perl distribution Perinci-CmdLine-Any-Bundled version 0.01), released on 2015-01-03.
+This document describes version 0.14 of Text::WideChar::Util (from Perl distribution Perinci-CmdLine-Any-Bundled version 0.02 version 0.01 version 0.01), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -424,20 +424,20 @@ This document describes version 0.14 of Text::WideChar::Util (from Perl distribu
      mbpad pad mbswidth mbswidth_height mbtrunc trunc mbwrap wrap);
 
  # get width as well as number of lines
- say mbswidth_height("red\nçº¢è²"); # => [4, 2]
+ say mbswidth_height("red\nÃÂ§ÃÂºÃÂ¢ÃÂ¨ÃÂÃÂ²"); # => [4, 2]
 
  # wrap text to a certain column width
  say mbwrap("....", 40);
 
  # pad (left, right, center) text to specified column width, handle multilines
  say mbpad("foo", 10);                          # => "foo       "
- say mbpad("çº¢è²", 10, "left");                 # => "      çº¢è²"
+ say mbpad("ÃÂ§ÃÂºÃÂ¢ÃÂ¨ÃÂÃÂ²", 10, "left");                 # => "      ÃÂ§ÃÂºÃÂ¢ÃÂ¨ÃÂÃÂ²"
  say mbpad("foo\nbarbaz\n", 10, "center", "."); # => "...foo....\n..barbaz..\n"
 
  # truncate text to a certain column width
- say mbtrunc("çº¢è²",  2); # => "çº¢"
- say mbtrunc("çº¢è²",  3); # => "çº¢"
- say mbtrunc("çº¢red", 3); # => "çº¢r"
+ say mbtrunc("ÃÂ§ÃÂºÃÂ¢ÃÂ¨ÃÂÃÂ²",  2); # => "ÃÂ§ÃÂºÃÂ¢"
+ say mbtrunc("ÃÂ§ÃÂºÃÂ¢ÃÂ¨ÃÂÃÂ²",  3); # => "ÃÂ§ÃÂºÃÂ¢"
+ say mbtrunc("ÃÂ§ÃÂºÃÂ¢red", 3); # => "ÃÂ§ÃÂºÃÂ¢r"
 
 =head1 DESCRIPTION
 
